#include "certificate.h"
#include <QDebug>
#include <QObject>

Certificate::Certificate(const QString& b64Line) :
    mValid(false),
    mShortDescription(QObject::tr("Invalid Certificate"))
{
    int ret = -1;
    char buf[2000];

    /* Cut of the first two chars (e.g. I: and decode) */
    QByteArray asn1data = QByteArray::fromBase64(
            b64Line.right(b64Line.size() - 2).toLatin1());

    x509_crt_init(&mX509Cert);
    ret = x509_crt_parse(&mX509Cert,
                         (const unsigned char*) asn1data.constData(),
                         asn1data.size());
    if (ret != 0) {
        qDebug() << "Parsing certificate failed with error: " << ret;
        return;
    }

    ret = x509_crt_info(buf, 2000, "", &mX509Cert);

    if (ret <= 0) {
        qDebug() << "Getting certificate info failed with error: " << ret;
        return;
    }

    /* In case of success the return value is the size of the information
     * written into buf
     * */

    mDetails = QString::fromUtf8(buf, ret);

    mShortDescription = mDetails; /* TODO */

    mValid = true;

    mBaseLine = b64Line;
}

Certificate::~Certificate()
{
    x509_crt_free(&mX509Cert);
}
